Change in osmo-ggsn[master]: gtp: Fix typo dublicate->duplicate

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

Pau Espin Pedrol gerrit-no-reply at lists.osmocom.org
Wed May 29 16:18:10 UTC 2019


Pau Espin Pedrol has uploaded this change for review. ( https://gerrit.osmocom.org/14263


Change subject: gtp: Fix typo dublicate->duplicate
......................................................................

gtp: Fix typo dublicate->duplicate

Change-Id: Ic572c216e74fa937dfd12f9f3dc03de18b6b123e
---
M gtp/gtp.c
1 file changed, 11 insertions(+), 11 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-ggsn refs/changes/63/14263/1

diff --git a/gtp/gtp.c b/gtp/gtp.c
index b50b592..a4f3ab2 100644
--- a/gtp/gtp.c
+++ b/gtp/gtp.c
@@ -383,13 +383,13 @@
  * requires the receiving GSN to send a response, with the same information
  * as in the original response. For most messages this happens automatically:
  *
- * Echo: Automatically dublicates the original response
+ * Echo: Automatically duplicates the original response
  * Create pdp context: The SGSN may send create context request even if
  *   a context allready exist (imsi+nsapi?). This means that the reply will
-     automatically dublicate the original response. It might however have
+     automatically duplicate the original response. It might however have
  *   side effects in the application which is asked twice to validate
  *   the login.
- * Update pdp context: Automatically dublicates the original response???
+ * Update pdp context: Automatically duplicates the original response???
  * Delete pdp context. Automatically in gtp0, but in gtp1 will generate
  *   a nonexist reply message.
  *
@@ -724,7 +724,7 @@
 	return 0;
 }
 
-static int gtp_dublicate(struct gsn_t *gsn, uint8_t version,
+static int gtp_duplicate(struct gsn_t *gsn, uint8_t version,
 		  struct sockaddr_in *peer, uint16_t seq)
 {
 	struct qmsg_t *qmsg;
@@ -984,8 +984,8 @@
 		 int fd, void *pack, unsigned len)
 {
 
-	/* Check if it was a dublicate request */
-	if (!gtp_dublicate(gsn, 0, peer, get_seq(pack)))
+	/* Check if it was a duplicate request */
+	if (!gtp_duplicate(gsn, 0, peer, get_seq(pack)))
 		return 0;
 
 	/* Send off reply to request */
@@ -1370,7 +1370,7 @@
 	uint8_t linked_nsapi = 0;
 	struct pdp_t *linked_pdp = NULL;
 
-	if (!gtp_dublicate(gsn, version, peer, seq))
+	if (!gtp_duplicate(gsn, version, peer, seq))
 		return 0;
 
 	pdp = &pdp_buf;
@@ -2072,8 +2072,8 @@
 	uint64_t imsi;
 	uint8_t nsapi;
 
-	/* Is this a dublicate ? */
-	if (!gtp_dublicate(gsn, version, peer, seq)) {
+	/* Is this a duplicate ? */
+	if (!gtp_duplicate(gsn, version, peer, seq)) {
 		return 0;	/* We allready send of response once */
 	}
 
@@ -2565,8 +2565,8 @@
 	int n;
 	int count = 0;
 
-	/* Is this a dublicate ? */
-	if (!gtp_dublicate(gsn, version, peer, seq)) {
+	/* Is this a duplicate ? */
+	if (!gtp_duplicate(gsn, version, peer, seq)) {
 		return 0;	/* We allready send off response once */
 	}
 

-- 
To view, visit https://gerrit.osmocom.org/14263
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-ggsn
Gerrit-Branch: master
Gerrit-MessageType: newchange
Gerrit-Change-Id: Ic572c216e74fa937dfd12f9f3dc03de18b6b123e
Gerrit-Change-Number: 14263
Gerrit-PatchSet: 1
Gerrit-Owner: Pau Espin Pedrol <pespin at sysmocom.de>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20190529/0e9dad2e/attachment.htm>


More information about the gerrit-log mailing list